@@ -7,8 +7,8 @@ from django.db import models
 class Migration(DataMigration):
 
     def forwards(self, orm):
-        "Write your forwards methods here."
-        # Note: Remember to use orm['appname.ModelName'] rather than "from appname.models..."
+        from sentry.constants import RESERVED_TEAM_SLUGS
+        from sentry.models import slugify_instance
         try:
             superuser = orm['auth.User'].objects.filter(is_superuser=True)[0]
         except IndexError:
@@ -17,16 +17,17 @@ class Migration(DataMigration):
         for project in orm['sentry.Project'].objects.filter(team__isnull=True):
             if not project.owner:
                 project.owner = superuser
-            project.team = orm['sentry.Team'].objects.create(
+            project.team = orm['sentry.Team'](
                 name=project.name,
                 owner=project.owner,
             )
+            slugify_instance(project.team, project.team.name, reserved=RESERVED_TEAM_SLUGS)
+            project.team.save()
             project.save()
 
 
-
     def backwards(self, orm):
-        "Write your backwards methods here."
+        pass
 
     models = {
         u'auth.group': {
